<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>LocaleConfig</name>
    <message>
        <location filename="../localeconfig.ui" line="31"/>
        <source>Re&amp;gion:</source>
        <translation>Ré&amp;gió:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="60"/>
        <source>De&amp;tailed Settings</source>
        <translation>&amp;Részletes beállítások</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="78"/>
        <source>&amp;Numbers:</source>
        <translation>&amp;Számok:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="107"/>
        <source>&amp;Time:</source>
        <translation>&amp;Idő:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="136"/>
        <source>Currenc&amp;y:</source>
        <translation>&amp;Pénznem:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="165"/>
        <source>Measurement &amp;Units:</source>
        <translation>&amp;Mértékrendszer:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="194"/>
        <source>Co&amp;llation and Sorting:</source>
        <translation type="unfinished">Egy&amp;bevetés és sorrend:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="226"/>
        <source>Examples</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="238"/>
        <source>Numbers:</source>
        <translation>Számok:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="258"/>
        <source>Time:</source>
        <translation>Idő:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="289"/>
        <source>Currency:</source>
        <translation>Pénznem:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="309"/>
        <source>Measurement Units:</source>
        <translation>Mértékrendszer:</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="164"/>
        <source>Unset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="226"/>
        <source>Current: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="370"/>
        <source>Format Settings Changed</source>
        <translation>Formátumbeállítások megváltoztak</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="371"/>
        <source>Do you want to save your changes? They will take effect the next time you log in.</source>
        <translation>Menti a változtatásokat? Ez a legközelebbi bejelentkezéskor lép érvénybe.</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="518"/>
        <source>Imperial UK</source>
        <translation>UK angol</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="522"/>
        <source>Imperial US</source>
        <translation>US angol</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="526"/>
        <source>Metric</source>
        <translation>Metrikus</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>LXQt Locale Configuration</source>
        <translation>LXQt területi beállítások</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Locale Settings</source>
        <translation>Területi beállítások</translation>
    </message>
</context>
</TS>
